import type { ClassNames } from "../types/index.js";
/**
 * Returns the default class names for the UI elements.
 *
 * This function generates a mapping of default class names for various UI
 * elements, day flags, selection states, and animations.
 *
 * @returns An object containing the default class names.
 * @group Utilities
 */
export declare function getDefaultClassNames(): ClassNames;
