"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MONTHS_PER_CYCLE = exports.MONTH_SEQUENCE_LEAP = exports.MONTH_SEQUENCE_COMMON = exports.HEBREW_EPOCH = exports.GREGORIAN_EPOCH = exports.MS_PER_DAY = void 0;
exports.MS_PER_DAY = 24 * 60 * 60 * 1000;
exports.GREGORIAN_EPOCH = Date.UTC(1, 0, 1);
exports.HEBREW_EPOCH = -2067381;
exports.MONTH_SEQUENCE_COMMON = [
    "tishrei",
    "cheshvan",
    "kislev",
    "tevet",
    "shevat",
    "adar",
    "nisan",
    "iyar",
    "sivan",
    "tamuz",
    "av",
    "elul",
];
exports.MONTH_SEQUENCE_LEAP = [
    "tishrei",
    "cheshvan",
    "kislev",
    "tevet",
    "shevat",
    "adarI",
    "adar",
    "nisan",
    "iyar",
    "sivan",
    "tamuz",
    "av",
    "elul",
];
exports.MONTHS_PER_CYCLE = 235;
