import React from "react";
import type { DayPickerProps } from "./types/index.js";
/**
 * Renders the DayPicker calendar component.
 *
 * @param initialProps - The props for the DayPicker component.
 * @returns The rendered DayPicker component.
 * @group DayPicker
 * @see https://daypicker.dev
 */
export declare function DayPicker(initialProps: DayPickerProps): React.JSX.Element;
