/**
 * Returns the last day of the Ethiopian month for the given date.
 *
 * @param date - The gregorian date to get the end of month for
 * @returns A new gregorian date representing the last day of the Ethiopian
 *   month
 */
export declare function endOfMonth(date: Date): Date;
