import type { DayPickerLocale } from "../classes/DateLib.js";
/**
 * Persian (Iran) locale for the Jalali (Persian) calendar, extended with
 * DayPicker-specific translations.
 */
export declare const faIRJalali: DayPickerLocale;
