"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.newDate = newDate;
const dateConversion_js_1 = require("../utils/dateConversion.js");
function newDate(year, monthIndex, day) {
    return (0, dateConversion_js_1.toGregorianDate)({ year, monthIndex, day });
}
