import type { FormatOptions as DateFnsFormatOptions } from "date-fns";
/** Hebrew calendar formatting override. */
export declare function format(date: Date, formatStr: string, options?: DateFnsFormatOptions): string;
