/**
 * Converts a number to Geez (Ethiopic) numerals.
 *
 * @param num - The number to convert
 * @returns The number in Geez numerals
 * @throws {Error} When input is 0 (Geez has no zero representation)
 */
export declare function toGeezNumerals(num: number): string;
