import type { DayPickerLocale } from "../classes/DateLib.js";
/**
 * Amharic (Ethiopia) locale backed by Intl for core names plus DayPicker
 * labels.
 */
export declare const amET: DayPickerLocale;
export default amET;
