import React from "react";
import type { DropdownProps } from "./Dropdown.js";
/**
 * Render a dropdown to navigate between months in the calendar.
 *
 * @group Components
 * @see https://daypicker.dev/guides/custom-components
 */
export declare function MonthsDropdown(props: DropdownProps): React.JSX.Element;
