/**
 * Checks if two dates fall in the same Ethiopian year.
 *
 * @param dateLeft - The first gregorian date to compare
 * @param dateRight - The second gregorian date to compare
 * @returns True if the dates are in the same Ethiopian year
 */
export declare function isSameYear(dateLeft: Date, dateRight: Date): boolean;
