"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getYear = getYear;
const index_js_1 = require("../utils/index.js");
/**
 * Get year
 *
 * @param {Date} date - The original date
 * @returns {number} The year
 */
function getYear(date) {
    const { year } = (0, index_js_1.toEthiopicDate)(date);
    return year;
}
