import type { CalendarDay } from "./CalendarDay.js";
/**
 * Represents a week in a calendar month.
 *
 * A `CalendarWeek` contains the days within the week and the week number.
 */
export declare class CalendarWeek {
    constructor(weekNumber: number, days: CalendarDay[]);
    /** The number of the week within the year. */
    weekNumber: number;
    /** The days that belong to this week. */
    days: CalendarDay[];
}
