"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMonth = getMonth;
const index_js_1 = require("../utils/index.js");
/**
 * Get month
 *
 * @param {Date} date - The original date
 * @returns {number} The zero-based month index
 */
function getMonth(date) {
    const { month } = (0, index_js_1.toEthiopicDate)(date);
    return month - 1; // Return zero-based month index
}
