import { type StartOfWeekOptions } from "date-fns";
/**
 * Start of week
 *
 * @param {Date} date - The original date
 * @param {StartOfWeekOptions} [options] - The options object
 * @returns {Date} The start of the week
 */
export declare function startOfWeek(date: Date, options?: StartOfWeekOptions): Date;
