import type { DayPickerLocale } from "../classes/DateLib.js";
/**
 * English (United States) locale for the Jalali (Persian) calendar, extended
 * with DayPicker-specific translations.
 */
export declare const enUSJalali: DayPickerLocale;
