declare const styles: {
  root: string;
  day: string;
  day_button: string;
  caption_label: string;
  button_next: string;
  button_previous: string;
  chevron: string;
  dropdowns: string;
  dropdown: string;
  dropdown_root: string;
  month_caption: string;
  months: string;
  month_grid: string;
  nav: string;
  weekday: string;
  week_number: string;
  today: string;
  selected: string;
  outside: string;
  disabled: string;
  hidden: string;
  range_start: string;
  range_middle: string;
  range_end: string;
  focusable: string;
};

export default styles;
