/**
 * Is same month
 *
 * @param {Date} dateLeft - The first date
 * @param {Date} dateRight - The second date
 * @returns {boolean} True if the two dates are in the same month
 */
export declare function isSameMonth(dateLeft: Date, dateRight: Date): boolean;
