/**
 * Difference in calendar months
 *
 * @param {Date} dateLeft - The later date
 * @param {Date} dateRight - The earlier date
 * @returns {number} The number of calendar months between the two dates
 */
export declare function differenceInCalendarMonths(dateLeft: Date, dateRight: Date): number;
