import { type EndOfWeekOptions } from "date-fns";
/**
 * End of week
 *
 * @param {Date} date - The original date
 * @param {EndOfWeekOptions} [options] - The options object
 * @returns {Date} The end of the week
 */
export declare function endOfWeek(date: Date, options?: EndOfWeekOptions): Date;
