"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDateLib = exports.enUS = exports.faIR = void 0;
exports.DayPicker = DayPicker;
const dateFnsJalali = __importStar(require("date-fns-jalali"));
const react_1 = __importDefault(require("react"));
const index_js_1 = require("./index.js");
const en_US_jalali_js_1 = require("./locale/en-US-jalali.js");
const fa_IR_jalali_js_1 = require("./locale/fa-IR-jalali.js");
const noonJalaliDateLib_js_1 = require("./noonJalaliDateLib.js");
/** Persian (Iran) Jalali locale with DayPicker labels. */
exports.faIR = fa_IR_jalali_js_1.faIRJalali;
/** English (US) Jalali locale with DayPicker labels. */
exports.enUS = en_US_jalali_js_1.enUSJalali;
/**
 * Renders the Persian calendar using the DayPicker component.
 *
 * @defaultValue
 * - `locale`: `faIR`
 * - `dir`: `rtl`
 * - `dateLib`: `jalaliDateLib` from `date-fns-jalali`
 * - `numerals`: `arabext` (Eastern Arabic-Indic)
 * @param props - The props for the Persian calendar, including locale, text
 *   direction, date library, and numeral system.
 * @returns The Persian calendar component.
 * @see https://daypicker.dev/docs/localization#persian-calendar
 */
function DayPicker(props) {
    const { locale: localeProp, dir, dateLib: dateLibProp, numerals, noonSafe, ...restProps } = props;
    const dateLib = (0, exports.getDateLib)({
        locale: localeProp,
        weekStartsOn: props.broadcastCalendar ? 1 : props.weekStartsOn,
        firstWeekContainsDate: props.firstWeekContainsDate,
        useAdditionalWeekYearTokens: props.useAdditionalWeekYearTokens,
        useAdditionalDayOfYearTokens: props.useAdditionalDayOfYearTokens,
        timeZone: props.timeZone,
        numerals: numerals ?? "arabext",
        noonSafe,
        overrides: dateLibProp,
    });
    return (react_1.default.createElement(index_js_1.DayPicker, { ...restProps, locale: localeProp ?? exports.faIR, numerals: numerals ?? "arabext", dir: dir ?? "rtl", dateLib: dateLib }));
}
/**
 * Returns the date library used in the Persian calendar.
 *
 * @param options - Optional configuration for the date library.
 * @returns The date library instance.
 */
const getDateLib = (options) => {
    const { noonSafe, overrides, ...dateLibOptions } = options ?? {};
    const baseOverrides = noonSafe && dateLibOptions.timeZone
        ? {
            ...dateFnsJalali,
            ...(0, noonJalaliDateLib_js_1.createJalaliNoonOverrides)(dateLibOptions.timeZone, {
                weekStartsOn: dateLibOptions.weekStartsOn,
                locale: dateLibOptions.locale,
            }),
        }
        : dateFnsJalali;
    return new index_js_1.DateLib(dateLibOptions, { ...baseOverrides, ...overrides });
};
exports.getDateLib = getDateLib;
