import type { DayPickerLocale } from "../classes/DateLib.js";
/**
 * Belarusian (Taraskievica) locale extended with DayPicker-specific
 * translations.
 */
export declare const beTarask: DayPickerLocale;
