import { toHebrewDate } from "../utils/dateConversion.js";
export function isSameMonth(dateLeft, dateRight) {
    const left = toHebrewDate(dateLeft);
    const right = toHebrewDate(dateRight);
    return left.year === right.year && left.monthIndex === right.monthIndex;
}
