/**
 * Checks if a given Ethiopic year is a leap year.
 *
 * @param year - The Ethiopic year.
 * @returns True if the year is a leap year; otherwise, false.
 */
export declare function isEthiopicLeapYear(year: number): boolean;
